#
# spec file for package kf6-kcoreaddons
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname kcoreaddons
# Full KF6 version (e.g. 6.10.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-kcoreaddons
Version:        6.10.0
Release:        1.1
Summary:        Utilities for core application functionality and accessing the OS
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  shared-mime-info
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6LinguistTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
Requires:       shared-mime-info >= 1.8

%description
KCoreAddons provides classes built on top of QtCore to perform various tasks
such as manipulating mime types, autosaving files, creating backup files,
generating random sequences, performing text manipulations such as macro
replacement, accessing user information and many more.

%package imports
Summary:        QML imports for kcoreaddons

%description imports
QML imports for kcoreaddons.

%package -n libKF6CoreAddons6
Summary:        Utilities for core application functionality and accessing the OS
Requires:       kf6-kcoreaddons = %{version}

%description -n libKF6CoreAddons6
KCoreAddons provides classes built on top of QtCore to perform various tasks
such as manipulating mime types, autosaving files, creating backup files,
generating random sequences, performing text manipulations such as macro
replacement, accessing user information and many more.

%package devel
Summary:        Utilities for core application functionality and accessing the OS
Requires:       libKF6CoreAddons6 = %{version}

%description devel
KCoreAddons provides classes built on top of QtCore to perform various tasks
such as manipulating mime types, autosaving files, creating backup files,
generating random sequences, performing text manipulations such as macro
replacement, accessing user information and many more. Development files.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
# ENABLE_PCH breaks the build locally with 'error: is pie differs in PCH file vs. current file'
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE -DENABLE_PCH:BOOL=FALSE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang kf6-kcoreaddons --all-name --with-qt --without-mo

%ldconfig_scriptlets -n libKF6CoreAddons6

%files
%{_kf6_appsdir}/mime/packages/kde6.xml
%{_kf6_debugdir}/kcoreaddons.categories
%{_kf6_debugdir}/kcoreaddons.renamecategories

%files imports
%{_kf6_qmldir}/org/kde/coreaddons/

%files -n libKF6CoreAddons6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6CoreAddons.so.*

%files devel
%doc %{_kf6_qchdir}/KF6CoreAddons.*
%{_kf6_includedir}/KCoreAddons/
%{_kf6_cmakedir}/KF6CoreAddons/
%dir %{_kf6_datadir}/jsonschema
%{_kf6_datadir}/jsonschema/kpluginmetadata.schema.json
%{_kf6_libdir}/libKF6CoreAddons.so

%files lang -f kf6-kcoreaddons.lang

%changelog
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * Provide more license for KAboutLicense
  * Add 7d4a6f31521 to git-blame-ignore-revs
  * Add Python bindings
  * It compiles fine without deprecated methods
  * kaboutdata: Add overload taking KAboutPerson and KAboutComponent
  * kfileutils: compare to basename in makeSuggestedName (kde#493270)
  * Apply 1 suggestion(s) to 1 file(s)
  * Link with libnetwork on Haiku
  * Don't put copyright statements if the license is not BSD
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * Make KJob::elapsedTime const
  * Fix absolute path generation into (not installed) header
  * KPluginMetaData: reduce string allocation
  * Update git blame ignore file
  * Reformat code with clang-format
  * Kjob: add elapsedTime() returns the ms the job ran
  * Add CI for static builds on Linux
  * Install QML module correctly when building statically
  * exportUrlsToPortal: use QScopeGuard::dismiss for the success code path
  * Update version to 6.8.0
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Make unit tests work with a static Qt build
  * kcoreaddonsplugin: Link against Qt6::Network
  * Restore KProcess on Android
  * Don't build kprocesstest for Android/iOS
  * Fix build on ios
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * exportUrlsToPortal: check for dbus error
  * KDirWatch: don't try inotify again if it has already failed
  * Relicense some files from lgpl2-only to lgpl2.1-or-later
  * ci: add Alpine/musl job
  * KPluginMetaData: Avoid reading metadata from plugin loader twice
  * kcoreaddons_add_plugin: Fix typo in error message
  * Fix configuring error when QtQml is not around
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * Enable cppcheck
  * Add missing license header
  * Add QML Format example
  * [qml/formats] Drop no longer needed function
  * Remove obsolete doc comment
  * Replace deprecated globalMatch with globalMatchView
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * Rename deprecated argument CLASSNAME to CLASS_NAME in ecm_add_qml_module() for KCoreAddonsPlugin
  * kurlmimedata: warn about problems while retrieving files from portal
  * decode os-release as UTF-8
  * use REQUIRED_QT_VERSION for dbus, too
  * provide USE_DBUS option to allow to turn on/off dbus parts
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * not all distros have /bin/true, e.g. NixOS lacks it
  * bundle license texts inside resource
  * Remove explicit maintainer from metainfo
  * kfilesystem: recognize nfs4 as KFileSystemType::Nfs
  * Replace KAboutDialog with KAboutApplicationDialog
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * Replace KAboutDialog with KAboutApplicationDialog
  * gitignore: add VS Code dir
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * Don't search for QtDBus on Windows/macOS/Android
  * KformatPrivate: fix deprecation enum arithmetic with float
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
  * Fix some compiler warning with mingw gcc
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kcoreaddons
